==> download.php?id=eMule0.49b_StulleMule_v6.1_src.zip: eMule0.49b_StulleMule_v6.1_src/eMule0.49b-StulleMule_v6.1-src/srchybrid/UserMsgs.h <==
#pragma once

// ALL WM_USER messages are to be declared here *after* 'WM_FIRST_EMULE_USER_MSG'
enum EUserWndMessages
{
	// *) Do *NOT* place any message *before* WM_FIRST_EMULE_USER_MSG !!
	// *) Do *NOT* use any WM_USER messages in the range WM_USER - WM_USER+0x100 !!
	UM_FIRST_EMULE_USER_MSG = (WM_USER + 0x100 + 1),

	// Taskbar
	UM_TASKBARNOTIFIERCLICKED,
	UM_TRAY_ICON_NOTIFY_MESSAGE,
	UM_CLOSE_MINIMULE,

	// Webserver
	WEB_GUI_INTERACTION,
	WEB_CLEAR_COMPLETED,
	WEB_FILE_RENAME,
	WEB_ADDDOWNLOADS,
	WEB_CATPRIO,
	WEB_ADDREMOVEFRIEND,
    WEB_COPYDATA, // MORPH leuk_he:run as ntservice v1..

	// VC
	UM_VERSIONCHECK_RESPONSE,

	// PC
	UM_PEERCHACHE_RESPONSE,

	UM_CLOSETAB,
	UM_QUERYTAB,
	UM_DBLCLICKTAB,

	UM_CPN_SELCHANGE,
	UM_CPN_DROPDOWN,
	UM_CPN_CLOSEUP,
	UM_CPN_SELENDOK,
	UM_CPN_SELENDCANCEL,

	UM_MEDIA_INFO_RESULT,
	UM_ITEMSTATECHANGED,
	UM_SPN_SIZED,
	UM_TABMOVED,
	UM_TREEOPTSCTRL_NOTIFY,
	UM_DATA_CHANGED,
	UM_OSCOPEPOSITION,
	UM_DELAYED_EVALUATE,
	UM_ARCHIVESCANDONE,

#ifdef USE_OFFICIAL_UPNP
	// UPnP
	UM_UPNP_RESULT,
#endif

	// Mighty Knife: CRC32-Tag - save rename
	UM_CRC32_RENAMEFILE,
	UM_CRC32_UPDATEFILE,
	// [end] Mighty Knife
	//MORPH START - Added by SiRoB, Version check
	UM_MVERSIONCHECK_RESPONSE,
	//MORPH END   - Added by SiRoB, Version check
	//MORPH START leuk_he run as a ntservice v1
	UM_SERVERSTATUS,
	//MORPH START leuk_he run as a ntservice v1
	// ==> StulleMule Version Check - Stulle
	UM_SVERSIONCHECK_RESPONSE
	// <== StulleMule Version Check - Stulle
};

==> download.php?id=eMule0.50a-StulleMule_v7.0-src.zip: eMule0.50a-StulleMule_v7.0-src/eMule0.50a-StulleMule_v7.0-src/srchybrid/UserMsgs.h <==
#pragma once

// ALL WM_USER messages are to be declared here *after* 'WM_FIRST_EMULE_USER_MSG'
enum EUserWndMessages
{
	// *) Do *NOT* place any message *before* WM_FIRST_EMULE_USER_MSG !!
	// *) Do *NOT* use any WM_USER messages in the range WM_USER - WM_USER+0x100 !!
	UM_FIRST_EMULE_USER_MSG = (WM_USER + 0x100 + 1),

	// Taskbar
	UM_TASKBARNOTIFIERCLICKED,
	UM_TRAY_ICON_NOTIFY_MESSAGE,
	UM_CLOSE_MINIMULE,

	// Webserver
	WEB_GUI_INTERACTION,
	WEB_CLEAR_COMPLETED,
	WEB_FILE_RENAME,
	WEB_ADDDOWNLOADS,
	WEB_CATPRIO,
	WEB_ADDREMOVEFRIEND,
    WEB_COPYDATA, // MORPH leuk_he:run as ntservice v1..

	// VC
	UM_VERSIONCHECK_RESPONSE,

	// PC
	UM_PEERCHACHE_RESPONSE,

	UM_CLOSETAB,
	UM_QUERYTAB,
	UM_DBLCLICKTAB,

	UM_CPN_SELCHANGE,
	UM_CPN_DROPDOWN,
	UM_CPN_CLOSEUP,
	UM_CPN_SELENDOK,
	UM_CPN_SELENDCANCEL,

	UM_MEDIA_INFO_RESULT,
	UM_ITEMSTATECHANGED,
	UM_SPN_SIZED,
	UM_TABMOVED,
	UM_TREEOPTSCTRL_NOTIFY,
	UM_DATA_CHANGED,
	UM_OSCOPEPOSITION,
	UM_DELAYED_EVALUATE,
	UM_ARCHIVESCANDONE,

#ifdef USE_OFFICIAL_UPNP
	// UPnP
	UM_UPNP_RESULT,
#endif

	// Mighty Knife: CRC32-Tag - save rename
	UM_CRC32_RENAMEFILE,
	UM_CRC32_UPDATEFILE,
	// [end] Mighty Knife
	//MORPH START - Added by SiRoB, Version check
	UM_MVERSIONCHECK_RESPONSE,
	//MORPH END   - Added by SiRoB, Version check
	//MORPH START leuk_he run as a ntservice v1
	UM_SERVERSTATUS,
	//MORPH START leuk_he run as a ntservice v1
	//MORPH START - Added by Stulle, New IP Filter by Ozzy [Stulle/Ozzy]
	UM_IPFFILTERAUTOVERCHECK_RESPONSE,
	//MORPH END   - Added by Stulle, New IP Filter by Ozzy [Stulle/Ozzy]
	// ==> StulleMule Version Check - Stulle
	UM_SVERSIONCHECK_RESPONSE
	// <== StulleMule Version Check - Stulle
};
